/* Copyright 2020, Michele Santullo
 * This file is part of memoserv.
 *
 * Memoserv is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * Memoserv is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with Memoserv.  If not, see <http://www.gnu.org/licenses/>.
 */

#include "memoserv_win.hpp"
#include "app_config.h"
#include "version_info_win.hpp"
#include <QMenu>
#include <QMenuBar>
#include <QApplication>

#include <iostream>

class QApplication;

namespace duck {

MemoservWin::MemoservWin(QApplication* app, QWidget *parent) :
    QMainWindow(parent)
{
	create_menu(app);
}

MemoservWin::~MemoservWin() noexcept = default;

void MemoservWin::create_menu(QApplication* app) {
	QMenu* const file_menu = menuBar()->addMenu(tr("&File"));
	{
		const QIcon open_icon = QIcon::fromTheme("document-open", QIcon(":/images/open.png"));
		const auto open_act = new QAction(open_icon, tr("&Open..."), this);
		open_act->setShortcut(QKeySequence(Qt::CTRL + Qt::Key_O));
		connect(open_act, &QAction::triggered, this, &MemoservWin::open);
		file_menu->addAction(open_act);
	}
	{
		const QIcon quit_icon = QIcon::fromTheme("application-exit");
		const auto quit_act = new QAction(quit_icon, tr("E&xit"), this);
		quit_act->setShortcut(QKeySequence(Qt::CTRL + Qt::Key_Q));
		connect(quit_act, &QAction::triggered, [this](){this->close();});
		file_menu->addAction(quit_act);
	}

	QMenu* const help_menu = menuBar()->addMenu(tr("&Help"));
	{
		const auto version_info_act = new QAction(tr("Version &info..."), this);
		help_menu->addAction(version_info_act);
		connect(version_info_act, &QAction::triggered, this, &MemoservWin::show_version_info);
	}
	{
		help_menu->addAction(tr("About &Qt..."), app, &QApplication::aboutQt);
	}
}

void MemoservWin::open() {
	std::cout << "MemoservWin::open()\n";
}

void MemoservWin::show_version_info() {
	std::cout << "MemoservWin::show_version_info()\n";
	VersionInfoWin vinfo(this);
	vinfo.setWindowModality(Qt::WindowModality::WindowModal);
	vinfo.exec();
}

} //namespace duck
